<?php
// Chinese language-texts for phpLiteAdmin
// Read our wiki on how to translate: http://code.google.com/p/phpliteadmin/wiki/Localization
$lang = array(
        "please_donate" => "請捐款",
        "free_software" => "本工具為自由軟體",
	"direction" => "LTR",
	"date_format" => 'Y/m/d H:i:s',  // 參考 http://php.net/manual/en/function.date.php 以瞭解每個字義所代表的意思
	"ver" => "版本",
	"for" => "for",
	"to" => "成",
	"go" => "執行",
	"yes" => "Yes",
	"sql" => "SQL",
	"csv" => "CSV",
	"csv_tbl" => "和CSV關聯的表格為",
	"srch" => "搜尋",
	"srch_again" => "再次搜尋",
	"login" => "登入",
	"logout" => "登出",
	"view" => "View",
	"confirm" => "確認",
	"cancel" => "取消",
	"save_as" => "另存檔案為",
	"options" => "選項",
	"no_opt" => "無選項",
	"help" => "説明",
	"installed" => "已安裝",
	"not_installed" => "未安裝",
	"done" => "完成",
	"insert" => "插入",
	"export" => "匯出",
	"import" => "匯入",
	"rename" => "更改名稱",
	"empty" => "清空",
	"drop" => "卸除",
	"tbl" => "表格",
	"chart" => "Chart",
	"err" => "錯誤",
	"act" => "動作",
	"rec" => "記錄數",
	"col" => "列",
	"cols" => "列",
	"rows" => "行",
	"edit" => "修改",
	"del" => "刪除",
	"add" => "增加",
	"backup" => "備份資料庫檔案",
	"before" => "之前",
	"after" => "之後",
	"passwd" => "輸入密碼",
	"passwd_incorrect" => "密碼錯誤.",
	"chk_ext" => "正在檢查支持SQLite的PHP擴充功能",
	"autoincrement" => "自動遞增",
	"not_null" => "非NULL",
	"attention" => "Attention",
	
	"sqlite_ext" => "SQLite擴充功能",
	"sqlite_ext_support" => "這顯示著在你所安裝的PHP版本中沒有受支援的SQLite擴充功能可取得. 你無法使用 %s 直到你安裝最新的版本.",
	"sqlite_v" => "SQLite版本",
	"sqlite_v_error" => "這顯示你的SQLite版本為 %s, 但是你所安裝的PHP版本並未包含所需的擴充功能來管理這個版本. 為了修復這問題, 一種方法是刪除本資料庫來讓 %s 自動生成, 另一種方法是以SQLite版本 %s 來手動建立.",
	"report_issue" => "本問題無法被正確解析. 請匯報資訊於",
	"sqlite_limit" => "由於SQLite的限制, 僅欄位名稱和資料類型可以被修改.",
	
	"php_v" => "PHP版本",
	
	"db_dump" => "資料庫轉存",
	"db_f" => "資料庫檔案",
	"db_ch" => "選擇資料庫",
	"db_event" => "資料庫事件",
	"db_name" => "檔案名稱",
	"db_rename" => "重新命名資料庫",
	"db_renamed" => "資料庫 '%s' 的檔案名稱已經修改為",
	"db_del" => "刪除資料庫",
	"db_path" => "路徑",
	"db_size" => "資料大小",
	"db_mod" => "修改時間",
	"db_create" => "建立新資料庫",
	"db_vac" => "資料庫, '%s', 已經壓縮.",
	"db_not_writeable" => "資料庫, '%s', 不存在並不能建立. 因為當前目錄, '%s', 不可寫入. 除非讓它可寫入, 否則程式不能使用.",
	"db_setup" => "設置資料庫, %s 出現問題. 將嘗試找出發生了什麼事情, 這樣你就可以更容易地解決這個問題",
	"db_exists" => "名稱為 '%s' 的資料庫, 檔案或目錄已存在.",
	
	"exported" => "已匯出",
	"struct" => "結構",
	"struct_for" => "結構",
	"on_tbl" => "在表格",
	"data_dump" => "數據轉存",
	"backup_hint" => "提示: 備份資料庫的最簡單方式是 %s.",
	"backup_hint_linktext" => "下載資料庫檔案",
	"total_rows" => "總共 %s 行",
	"total" => "總數",
	"not_dir" => "您指定的目錄掃描資料庫不存在或不是一個目錄。",
	"bad_php_directive" => "PHP指令, 啟用'register_globals的'. 這是不恰當的. 你需要禁用它, 然後再繼續.",
	"page_gen" => "頁面呈現 %s 秒.",
	"powered" => "Powered by",
	"remember" => "記住登入狀態",
	"no_db" => "歡迎來到 %s. 你似乎選擇要用phpLiteAdmin來管理資料庫. 然而, %s 無法找到任何有效的SQLite資料庫. 您可以使用下面的表格來建立你的第一個資料庫.",
	"no_db2" => "您指定的目錄不包含任何現有的資料庫管理, 目錄不可寫入. 這意味著你不能用%s建立任何新的資料庫. 要麼使目錄可寫入或手動上傳目錄資料庫.",
	
	"create" => "建立",
	"created" => "建立完畢",
	"create_tbl" => "建立新表格",
	"create_tbl_db" => "在資料庫中建立新表格",
	"create_trigger" => "建立新觸發器在表格",
	"create_index" => "建立新索引在表格",
	"create_index1" => "建立索引",
	"create_view" => "建立新視圖",
	
	"trigger" => "觸發器",
	"triggers" => "觸發器",
	"trigger_name" => "觸發器名稱",
	"trigger_act" => "觸發器動作",
	"trigger_step" => "觸發器步驟 (分號終止)",
	"when_exp" => "WHEN 條件 (輸入條件不包括 'WHEN')",
	"index" => "索引",
	"indexes" => "索引",
	"index_name" => "索引名稱",
	"name" => "名稱",
	"unique" => "唯一值",
	"seq_no" => "序列號碼",
	"emptied" => "已被清空",
	"dropped" => "已被刪除",
	"renamed" => "已被改名為",
	"altered" => "變更成功",
	"inserted" => "已插入",
	"deleted" => "已刪除",
	"affected" => "受影響",
	"blank_index" => "索引名必須非空白.",
	"one_index" => "必須至少指定一個索引列.",
	"docu" => "線上資料",
	"license" => "使用協議",
	"proj_site" => "官方網站",
	"bug_report" => "這或許是一個需要彙報的漏洞在",
	"return" => "返回",
	"browse" => "瀏覽",
	"fld" => "欄位",
	"fld_num" => "表格中欄位數",
	"fields" => "欄位",
	"type" => "類型",
	"operator" => "運算符號",
	"val" => "值",
	"update" => "更新",
	"comments" => "註解",
	
	"specify_fields" => "你必須指定表格中的欄位的數量.",
	"specify_tbl" => "你必須指定表格名稱.",
	"specify_col" => "你必須指定一個列.",
	
	"tbl_exists" => "已存在同名表格.",
	"show" => "顯示",
	"show_rows" => "顯示 %s 行. ",
	"showing" => "正在顯示",
	"showing_rows" => "顯示行",
	"query_time" => "(查詢使用 %s 秒)",
	"syntax_err" => "你查詢的語法有出現問題 (查詢未被執行)",
	"run_sql" => "在資料庫 '%s' 中執行查詢",
	
	"ques_empty" => "你確定要清空表格 '%s'?",
	"ques_drop" => "你確定要刪除表格 '%s'?",
	"ques_drop_view" => "你確定要刪除視圖 '%s'?",
	"ques_del_rows" => "你確定要刪除行 %s 從表格 '%s'?",
	"ques_del_db" => "你確定要刪除資料庫 '%s'?",
	"ques_del_col" => "你確定要刪除列 %s 從表格 '%s'?",
	"ques_del_index" => "你確定要刪除索引 '%s'?",
	"ques_del_trigger" => "你確定要刪除觸發器 '%s'?",
	
	"export_struct" => "匯出結構",
	"export_data" => "匯出資料",
	"add_drop" => "刪除已存在的表格",
	"add_transact" => "增加交易",
	"fld_terminated" => "欄位分隔符號",
	"fld_enclosed" => "欄位封閉符號",
	"fld_escaped" => "欄位轉義符號",
	"fld_names" => "欄位名稱在第一行",
	"rep_null" => "替換NULL為",
	"rem_crlf" => "移除欄位中的空字元CRLF",
	"put_fld" => "把欄位名稱放在第一行",
	"null_represent" => "NULL描述為",
	"import_suc" => "匯入成功.",
	"import_into" => "匯入",
	"import_f" => "匯入文件",
	"rename_tbl" => "表格 '%s' 更改名稱為",
	
	"rows_records" => "行, 開始於 # ",
	"rows_aff" => "列受影響. ",
	
	"as_a" => "as a",
	"readonly_tbl" => "'%s' 是一個視圖, 意味著它是一個只能使用 SELECT 語法的唯讀表格. 你不能修改或插入記錄.",
	"chk_all" => "全選",
	"unchk_all" => "取消全選",
	"with_sel" => "選中項目",
	
	"no_tbl" => "資料庫中沒有表格",
	"no_chart" => "如果你可以看到這一點, 就意味著不能生成圖表. 想查看你的資料可能不適合圖表.",
	"no_rows" => "對於你所選擇的範圍, 在本表格中不存在任一列.",
	"no_sel" => "你尚未做出選擇.",
	
	"chart_type" => "圖表類型",
	"chart_bar" => "柱狀圖",
	"chart_pie" => "圓形圖",
	"chart_line" => "線圖",
	"lbl" => "標籤",
	"empty_tbl" => "表格是空的.",
	"click" => "點擊",
	"insert_rows" => "來插入資料.",
	"restart_insert" => "重新插入 ",
	"ignore" => "忽略",
	"func" => "函數",
	"new_insert" => "插入新行",
	"save_ch" => "保存修改",
	"def_val" => "預設值",
	"prim_key" => "主鍵",
	"tbl_end" => "個新欄位在表格末端",
	"query_used_table" => "用於建立此表格的查詢",
	"query_used_view" => "用於建立視圖的查詢",
	"create_index2" => "建立新索引使用",
	"create_trigger2" => "建立新觸發器",
	"new_fld" => "在表格 '%s' 中添加新欄位",
	"add_flds" => "增加欄位",
	"edit_col" => "修改列 '%s'",
	"vac" => "壓縮",
	"vac_desc" => "大型資料庫有時需要在伺服器上進行壓縮. 點擊下面的按鈕開始壓縮資料庫 '%s'.",
	"event" => "事件",
	"each_row" => "在每行",
	"define_index" => "定義索引屬性",
	"dup_val" => "重複值",
	"allow" => "允許",
	"not_allow" => "不允許",
	"asc" => "升冪[ASC]",
	"desc" => "降冪[DESC]",
	"warn0" => "你已經受到警告.",
	"warn_passwd" => "你正在使用默認的密碼, 這是比較危險的. 你可以很方便的在 %s 檔案中進行修改.",
	"sel_state" => "選擇語法",
	"delimit" => "分隔符號",
	"back_top" => "回到上面",
	"choose_f" => "選擇檔案",
	"instead" => "取代",
	"define_in_col" => "定義索引列",
	
	"delete_only_managed" => "你僅能刪除由本工具管理的資料庫!",
	"rename_only_managed" => "你僅能更改由本工具管理的資料庫名稱!",
	"db_moved_outside" => "如果不是因為你曾經嘗試移動資料庫到不再被管理的資料夾中, 就要確定是否因為喪失權力所以導致動作失敗.",
	"extension_not_allowed" => "你所提供的擴充功能不在被允許的擴充功能清單中. 請使用以下的擴充功能之一",
	"add_allowed_extension" => "你可以新增你的擴充功能到設定檔中的下面列表 \$allowed_extensions",
	"directory_not_writable" => "這資料庫檔案本身是可寫入的, 不過為了寫入資料, 其上層資料夾也需要可寫入. 這是因為SQLite會為了鎖定而將暫存檔放置此處.",
	"tbl_inexistent" => "表格 %s 並不存在",

	// 當更動表格發生錯誤所產生的訊息. 你不需要翻譯它們.
	"alter_failed" => "更動表格 %s 失敗",
	"alter_tbl_name_not_replacable" => "無法以暫存名稱取代本表格名稱",
	"alter_no_def" => "沒 ALTER 定義",
	"alter_parse_failed" =>"無法解析 ALTER 定義",
	"alter_action_not_recognized" => "ALTER 動作無法被識別",
	"alter_no_add_col" => "在 ALTER 語法中沒有偵測到要增加的欄位",
	"alter_pattern_mismatch"=>"模式無法配對到你原本的 CREATE TABLE 語法",
	"alter_col_not_recognized" => "無法識別新的或舊的欄位名稱",
	"alter_unknown_operation" => "未知的 ALTER 操作!",
	
	/* Help documentation */
	"help_doc" => "説明資料",
	"help1" => "SQLite擴充功能庫",
	"help1_x" => "%s 使用PHP擴充功能庫以允許和SQLite資料庫進行溝通. 目前, %s 支援 PDO, SQLite3, 和SQLiteDatabase. PDO和SQLite3兩者搭配SQLite版本3, 而SQLiteDatabase搭配版本2. 所以如果你的PHP安裝檔包含多於一個SQLite擴充功能庫, PDO和SQLite3將會優先採用以使用較好的技術. 不過, 如果你擁有的資料庫屬於SQLite第2版的資料, %s 將會對那些資料庫強制使用SQLiteDatabase. 並非所有資料庫都必須是相同版本. 不過在資料庫建立中, 將會採用最先進的擴充功能.",
	"help2" => "建立新資料庫",
	"help2_x" => "當你建立一個新資料庫, 如果你沒自己添加副檔名, 你所輸入的名稱後面將會附加適當的副檔名 (.db, .db3, .sqlite 等) . 所建立的資料庫將存在於你所指定的 \$directory 變數的資料夾中.",
	"help3" => "表格 vs. 視圖",
	"help3_x" => "在主要資料庫頁面上, 會有表格與視圖的列表. 因為視圖為唯讀, 所以一些操作將會失效. 這些無效操作將會在本應該顯示於視圖的該列上而忽略掉. 如果你想改變視圖的資料, 你應該卸除該視圖, 並且以合適的 SELECT 語法去搜尋既存的表格來建立一個新視圖. 更多資訊請參考: <a href='http://en.wikipedia.org/wiki/View_(database)' target='_blank'>http://en.wikipedia.org/wiki/View_(database)</a>",
	"help4" => "為一個新視圖撰寫選取語法",
	"help4_x" => "當你建立一個新視圖, 你必須撰寫一個SQL SELECT 語法來取用其資料. 一個視圖僅簡化成唯讀表格, 也就是可以像一般表格一樣被讀取且搜尋, 不過並無法執行插入, 欄位修改或列位更動. 它僅供作方便取用資料之用.",
	"help5" => "匯出結構到SQL檔案",
	"help5_x" => "在匯出結構到SQL檔案過程中, 你可以選擇撰寫包含建立表格與欄位的語法.",
	"help6" => "匯出資料到SQL檔案",
	"help6_x" => "在匯出資料到SQL檔案過程中, 你可以選擇撰寫包含以表格中當前記錄來搬移該表格的語法.",
	"help7" => "添加卸除的表格到已匯出的SQL檔案",
	"help7_x" => "在匯出資料到既存的SQL檔案過程中, 在添加資料前, 你可以選擇撰寫DROP語法來卸除現存的表格, 這樣在嘗試建立已經存在的表格時才不會發生問題.",
	"help8" => "增加交易到已匯出的SQL檔案",
	"help8_x" => "在匯出資料到既存的SQL檔案過程中, 你可以選擇以交易方式封裝語法, 這樣當在取用已匯出的資料檔的重要過程中時發生錯務, 該資料庫就可以還原到先前的狀態, 以防在搬移資料庫時發生資料部分更新.",
	"help9" => "增加註解到已匯出的SQL檔案",
	"help9_x" => "在匯出資料到既存的SQL檔案過程中, 你可以選擇包含註解來說明解釋每一個步驟, 這樣人們才能更瞭解正在發生什麼事."
	
	);
?>
