/*
phpLiteAdmin Shadow Theme 
Created by Leo Van Nieuwenhuyse on 20/05/2015
based on phpLiteAdmin Modern Theme Created by Petar Koretic on 01/04/2013

Since this template uses CSS3-features, 
Internet Explorer 10 or Higher, Chrome 26 or higher, Firefox 16 or higher, Safari 6.1 or higher, Opera 12.1 or higher
are required to get the full UI experience.

Older browsers will also render but without rounded corners, shadows and gradiants. Time to get rid of them!
*/
html,body 
{
	font: 100% "Segoe UI","Trebuchet MS", arial, helvetica, sans-serif; 
}
#headerlinks a, legend b,fieldset a
{
   font-weight: lighter;
}
/* overall styles for entire page */
body
{
	margin: 0px;
	padding: 0px;
	font-size: 1em;
	color: #000;
}
/* general styles for hyperlink */
a
{
	color: #15c;
	text-decoration: none;
	cursor :pointer;
    text-shadow: 0 1px 1px #FFF; 	
}
a:hover
{
	color: #00A;
}
/* horizontal rule */
hr
{
  height:1px;
	border: 0;
	color: #d2d2d2;
	background: #d2d2d2;
	width: 100%;	
}
/* logo text containing name of project */
h1
{
	margin: 0px;
	padding: 5px;
	font-size: 1.85em;
	text-align: center;
	margin-bottom: 10px;
    border-radius: 10px 10px 0px 0px;	
	
}
/* version text within the logo */
h1 #version
{
	font-size: 0.65em;
    color:#FFF;
    text-shadow: 2px 2px 0px #666;  
}
/* logo text within logo */
h1 #logo
{
	color:#FFF;
    text-shadow: 3px 3px 3px #666;
}
/* general header for various views */
h2
{
	margin:0px;
	padding:0px;
	font-size:1em;
	margin-bottom:20px;
}
select
{
 background: #FFF;
 border: 1px solid #CCC;
 height:27px;
 line-height:27px;
 vertical-align:middle;
}
[multiple]
{
 height:100%;
}

/* input buttons and areas for entering text */
textarea
{
  background:#FBFBFF;
  padding:5px;
  margin: -7px;
  margin-top: 5px;
  margin-bottom: 7px;  
  outline: none;  
  border:1px solid #FFF;
  border-color:#D2D2DC #E6E6F0 #E6E6F0 #D2D2DC;
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  border-radius: 7px; 

}
input[type=text],
input[type=password],
input[type=file],
select
{
  background:#FBFBFF;
  display: inline-block;
  height: 25px;
  line-height:25px;
  margin-top: 0px;
  margin-bottom: 5px;
  padding: 0 8px;
  vertical-align:middle;
  border:1px solid #FFF;
  border-color:#D2D2DC #E6E6F0 #E6E6F0 #D2D2DC;
  box-shadow: 1px 1px 0 #eeeeee inset;  
  border-radius: 7px;  
}
/* just input buttons */
input.btn
{
  cursor:pointer; 
  vertical-align:middle;
  display:inline-block;
  margin: 0;
  outline:none;
  border:1px solid #C8C8C8;  
  border-bottom-color:#B4B4B4;
  border-right-color:#AAAAAA;
  height:27px;
  padding:0 10px;
}
input.btn:hover
{
  border-color:#D2D2D2;
}
/* general styles for hyperlink */
fieldset,.confirm
{
	padding:15px;
	background:#f9f9f9;
    border: 1px solid #B4B4FA;
	border-radius: 7px;  
	box-shadow: 3px 3px 1px #999;
}
legend 
{
	padding: 2px 7px 2px 7px;	
	font-size: smaller;
	background: #81a8ce;
	color: #fff;
	border: 1px solid #B4B4FA;
    border-radius: 7px;		
	box-shadow: 3px 3px 1px #ccc;
}
legend a
{
    color: #fff;
	text-shadow: 0 0px 0px #FFF;
}
legend a:hover
{
	color: #ccc;
}
/* outer div that holds everything */
#container
{
	padding:10px;
}
/* div of left box with log, list of databases, etc. */
#leftNav
{
	float:left;
	width:250px;
	padding:0px;
	padding-bottom:15px;
	border: 0px;
    border-radius: 7px;		
    background: #AFC7DF; 	
	box-shadow: 5px 5px 2px #ccc;	
	margin-right: 3px;
}
/* div holding the content to the right of the leftNav */
#content
{
	overflow:hidden;
	padding-left:10px;
}
/* div holding the login fields */
#loginBox
{
	width:500px;
	margin-left:auto;
	margin-right:auto;
	margin-top:50px;
	border:1px solid #B4B4FA;
    border-radius: 10px;	
	box-shadow: 5px 5px 2px #ccc;
	background:#AFC7DF;
}
#loginBox div
{
    background: #AFC7DF; 	
	border-radius: 0px 0px 10px 10px;
}
/* div under tabs with tab-specific content */
#main
{
    border: 1px solid #B4B4FA;
    border-radius: 0px 7px 7px 7px;	
	padding:15px;
	overflow:auto;
	background:#FFF;
	box-shadow: 3px 3px 2px #ccc;	
	background: #FFF;
}
#main_column
{
  background:#FFF; 
		
}

/* odd-numbered table rows */
.td1
{
	background:#fff;
	text-align:right;
	font-size:0.9em;
	padding-left:10px;
	padding-right:10px;
}
/* even-numbered table rows */
.td2
{
	background:#EEE;
	text-align:right;
	font-size:0.9em;
	padding-left:10px;
	padding-right:10px;
}
/* table column headers */
.tdheader
{
    /*border:1px solid #B4B4FA;*/
	font-weight:bold;
	font-size:0.9em;
	padding-left:10px;
	padding-right:10px;
}
/* tab navigation for each table */
.tab
{
	display:block;
	padding:5px;
	padding-right:8px;
	padding-left:8px;
    border:1px solid #B4B4FA;
    border-radius: 7px 7px 0px 0px;	
	margin-right:3px;
	float:left;
	position:relative;
	top:1px;
	padding-bottom:4px;
    background: linear-gradient(to bottom, #cccccc ,#ffffff); 
	color: grey;	
	text-shadow: -1px -1px 0px #fff; 
    font-weight: 600;     	
}
.tab:hover
{
    font-weight: 600;
}
/* pressed state of tab */
.tab_pressed
{
	display:block;
	padding:5px 8px;
    border:1px solid #B4B4FA;
    border-radius: 7px 7px 0px 0px;		
	margin-right:3px;
	float:left;
	border-bottom-style:none;
	position:relative;
	top:1px;
	cursor:default;
    background: linear-gradient(to bottom, #cccccc ,#ffffff); 
    font-weight: bold;
	text-shadow: -1px -1px 0px #fff;  
}
.body_tbl 
{

}
.left_td {

}
/* tooltip styles */
#tt
{
	position:absolute;
	display:block;
}
#tttop
{
	display:block;
	height:5px;
	margin-left:5px;
	overflow:hidden
}
#ttcont
{
	display:block;
	padding:2px 12px 3px 7px;
	margin-left:5px;
	background:#f3cece;
	color:#333
}
#ttbot
{
	display:block;
	height:5px;
	margin-left:5px;
	overflow:hidden
}
h1
{
	background: linear-gradient(to bottom, #81a8ce , #AFC7DF ); /* #d4e2ef);	*/  
}
input.btn
{
  border-radius: 7px;
  margin-left: 1px;  
  margin-top: 0px;
  margin-bottom: 5px;  
}
input.btn,  .tdheader
{
  background: linear-gradient(to bottom, #fdfdfd,#ccc); /* W3C */		  
}

table 
{ 
  border-collapse: collapse; 
}
table td 
{ 
  border: 1px solid #fff; 
  padding:5px; 
}
#headerlinks
{
   text-align:center;   
}

