<?php
// Russian language file by Boris Kurshev (13dagger)
// Read our wiki on how to translate: https://bitbucket.org/phpliteadmin/public/wiki/Localization
$lang = array(
	"direction" => "LTR",
	"date_format" => 'g:ia \o\n F j, Y (T)',  // see http://php.net/manual/en/function.date.php for what the letters stand for
	"ver" => "версия",
	"for" => "для",
	"to" => "в",
	"go" => "Готово",
	"yes" => "Готово",
	"sql" => "SQL",
	"csv" => "CSV",
	"csv_tbl" => "Таблица, к которой относится CSV",
	"srch" => "Поиск",
	"srch_again" => "Выполнить Другой Поиск",
	"login" => "Войти",
	"logout" => "Выйти",
	"view" => "Просмотр",
	"confirm" => "Подтвердить",
	"cancel" => "Отмена",
	"save_as" => "Сохранить как",
	"options" => "Настройки",
	"no_opt" => "Без настроек",
	"help" => "Помощь",
	"installed" => "установлено",
	"not_installed" => "не установлено",
	"done" => "готово",
	"insert" => "Вставить",
	"export" => "Экспорт",
	"import" => "Импорт",
	"rename" => "Переименовать",
	"empty" => "Очистить",
	"drop" => "Удалить",
	"tbl" => "Таблица",
	"chart" => "График",
	"err" => "ОШИБКА",
	"act" => "Действие",
	"rec" => "Записи",
	"col" => "Столбец",
	"cols" => "Столбцы",
	"rows" => "строка(и)",
	"edit" => "Редактировать",
	"del" => "Удалить",
	"add" => "Добавить",
	"backup" => "Создать бэкап файла базы",
	"before" => "До",
	"after" => "После",
	"passwd" => "Пароль",
	"passwd_incorrect" => "Неверный пароль.",
	"chk_ext" => "Проверка доступных расширений PHP для SQLite",
	"autoincrement" => "Autoincrement",
	"not_null" => "Not NULL",
	"attention" => "Внимание",
	"none" => "None",   #todo: translate
	"as_defined" => "As defined",  #todo: translate
	"expression" => "Expression",  #todo: translate
	
	"sqlite_ext" => "расширение SQLite",
	"sqlite_ext_support" => "Похоже, не установлено ни одной поддерживаемой библиотеки SQLite в вашей сборке PHP. Вы не можете использовать %s, пока не установите хотя бы одну из них.",
	"sqlite_v" => "версия SQLite",
	"sqlite_v_error" => "Похоже, ваша база данных SQLite версии %s, но ваша сборка PHP не содержит необходимых библиотек для работы с этой версией. Для решения проблемы, либо удалите базу и позвольте %s создать ее автоматически, либо создайте ее вручную, используя SQLite версии %s.",
	"report_issue" => "Проблема не может быть диагностирована корректно. Пожалуйста, сообщите о проблеме.",
	"sqlite_limit" => "Из-за ограничений SQLite, только имя поля и тип данных могут быть изменены.",
	
	"php_v" => "версия PHP",
	
	"db_dump" => "дамп базы данных",
	"db_f" => "файл базы данных",
	"db_ch" => "Изменить Базу Данных",
	"db_event" => "Событие Базы Данных",
	"db_name" => "Имя базы данных",
	"db_rename" => "Переименовать базу данных",
	"db_renamed" => "База данных '%s' была переименована в",
	"db_del" => "Удалить базу данных",
	"db_path" => "Путь к базе данных",
	"db_size" => "Размер базы данных",
	"db_mod" => "Последние изменения базы данных",
	"db_create" => "Создать базу данных",
	"db_vac" => "К базе данных '%s' была применена команда VACUUM.",
	"db_not_writeable" => "База данных '%s' не существует и не может быть создана, т.к. в директории '%s' закрыты права на запись. Приложение бесполезно, пока вы не предоставите права.",
	"db_setup" => "При установке БД %s случилась ошибка. Для помощи в решении проблемы предпримется еще попытка.",
	"db_exists" => "База данных, файл или директория с именем '%s' уже существует.",
	
	"exported" => "Экспортировано",
	"struct" => "Структура",
	"struct_for" => "структура для",
	"on_tbl" => "в таблице",
	"data_dump" => "Дамп данных для",
	"backup_hint" => "Подсказка: самый простой путь создать бэкап бд - %s.",
	"backup_hint_linktext" => "скачать файл базы данных",
	"total_rows" => "суммарно %s строк",
	"total" => "Всего",
	"not_dir" => "Директория, которую вы указали для сканирования, не существует или не является директорией.",
	"bad_php_directive" => "Похоже параметр PHP 'register_globals' включен. Безобразие. Отключите его для продолжения работы.",
	"page_gen" => "Время генерации страницы - %s сек.",
	"powered" => "На базе",
	"remember" => "Запомнить",
	"no_db" => "Добро пожаловать в %s. Похоже, вы выбрали директорию для поиска баз даных. Тем не менее, %s не может найти валидных баз данных SQLite. Вы можете создать новую базу с помощью формы ниже.",
	"no_db2" => "Директория, которую вы указали, не содержит баз данных и не предоставляет прав на запись. Таким образом, вы не можете создать новую базу, используя %s. Либо предоставьте права на запись, либо загрузите базы данных в директорию вручную.",
	
	"create" => "Создать",
	"created" => "Была создана",
	"create_tbl" => "Создать новую таблицу",
	"create_tbl_db" => "Создать новую таблицу в базе данных",
	"create_trigger" => "Создание нового триггера в таблице",
	"create_index" => "Создание нового индекса в таблице",
	"create_index1" => "Создать Индекс",
	"create_view" => "Создание нового Представления(VIEW) в базе данных",
	
	"trigger" => "Триггер",
	"triggers" => "Триггеры",
	"trigger_name" => "имя Триггера",
	"trigger_act" => "Действие Триггера",
	"trigger_step" => "Шаги Триггера (разделены точкой с запятой)",
	"when_exp" => "выражение WHEN (напишите выражение без 'WHEN')",
	"index" => "Индекс",
	"indexes" => "Индексы",
	"index_name" => "имя Индекса",
	"name" => "Имя",
	"unique" => "Уникальный",
	"seq_no" => "Номер Последовательности",
	"emptied" => "была очищена",
	"dropped" => "была удалена",
	"renamed" => "была переименована в",
	"altered" => "была успешно изменена",
	"inserted" => "вставлено",
	"deleted" => "удалено",
	"affected" => "затронуто",
	"blank_index" => "Имя индекса не может быть пустым.",
	"one_index" => "Вы должны указать как минимум 1 индексный столбец.",
	"docu" => "Документация",
	"license" => "Лицензирование",
	"proj_site" => "Сайт проекта",
	"bug_report" => "Похоже, это баг, который стоит отправить в",
	"return" => "Назад",
	"browse" => "Просмотр",
	"fld" => "Поле",
	"fld_num" => "Количество полей",
	"fields" => "Поля",
	"type" => "Тип",
	"operator" => "Оператор",
	"val" => "Значение",
	"update" => "Изменить",
	"comments" => "Комментарии",
	
	"specify_fields" => "Вы должны указать количество полей таблицы.",
	"specify_tbl" => "Вы должны указать имя таблицы.",
	"specify_col" => "Вы должны указать столбец.",
	
	"tbl_exists" => "Таблица с таким именем уже существует.",
	"show" => "Показать",
	"show_rows" => "Показано строк - %s. ",
	"showing" => "Отображение",
	"showing_rows" => "Отображение строк",
	"query_time" => "(Запрос занял %s сек)",
	"syntax_err" => "В синтаксисе запроса ошибка (Запрос не был выполнен)",
	"run_sql" => "Выполнить SQL запрос(ы) в базе данных '%s'",
	
	"empty" => "Вы уверены, что хотите очистить таблицу '%s'?",
	"ques_drop" => "Вы уверены, что хотите удалить таблицу '%s'?",
	"ques_drop_view" => "Вы уверены, что хотите удалить представление '%s'?",
	"ques_del_rows" => "Вы уверены, что хотите удалить строку(и) %s из таблицы '%s'?",
	"ques_del_db" => "Вы уверены, что хотите удалить базу данных '%s'?",
	"ques_column_delete" => "Вы уверены, что хотите удалить поле(я) %s из таблицы '%s'?",
	"ques_del_index" => "Вы уверены, что хотите удалить индекс '%s'?",
	"ques_del_trigger" => "Вы уверены, что хотите удалить триггер '%s'?",
	#todo: translate
	"ques_primarykey_add" => "Are you sure you want to add a primary key for the column(s) %s in table '%s'?",
	
	"export_struct" => "Экспорт структуры",
	"export_data" => "Экспорт данных",
	"add_drop" => "Добавить DROP TABLE",
	"add_transact" => "Добавить TRANSACTION",
	"fld_terminated" => "Поле заканчивается",
	"fld_enclosed" => "Поле окружено",
	"fld_escaped" => "Поле экранировано",
	"fld_names" => "Имена полей в первой строке",
	"rep_null" => "Заменить NULL на",
	"rem_crlf" => "Убрать CRLF символы из полей",
	"put_fld" => "Положить имена полей в первую строку",
	"null_represent" => "NULL представлен как",
	"import_suc" => "Импорт успешно завершен.",
	"import_into" => "Импорт в",
	"import_f" => "Файл для импорта",
	"rename_tbl" => "Переименовать таблицу '%s' в",
	
	"rows_records" => "строк(а), начиная с # ",
	"rows_aff" => "строк(а) затронуто. ",
	
	"as_a" => "как",
	"readonly_tbl" => "'%s' - представление, т.е. SELECT, который трактуется, как таблица только для чтения. Вы не можете вставлять или редактировать строки.",
	"chk_all" => "Выделить все",
	"unchk_all" => "Снять выделение",
	"with_sel" => "Применить к выбранным",
	
	"no_tbl" => "В базе данных нет таблиц.",
	"no_chart" => "Если вы читаете это, значит график не может быть сгенерирован. Возможно, данные, которые вы просматриваете, не подходят для построения графика.",
	"no_rows" => "В таблице нет строк выбранного вами промежутка.",
	"no_sel" => "Вы ничего не выбрали.",
	
	"chart_type" => "Тип диаграммы",
	"chart_bar" => "Столбчатая Диаграмма",
	"chart_pie" => "Круговая Диаграмма",
	"chart_line" => "Линия (График)",
	"lbl" => "Обозначения",
	"empty_tbl" => "Эта таблица пустая.",
	"click" => "Нажмите здесь",
	"insert_rows" => "для вставки строк.",
	"restart_insert" => "Вывести форму добавления для ",
	"ignore" => "Игнорировать",
	"func" => "Функция",
	"new_insert" => "Вставить Как Новую Строку",
	"save_ch" => "Сохранить Изменения",
	"def_val" => "Значение По Умочанию",
	"prim_key" => "Первичный Ключ",
	"tbl_end" => "полей в конец таблицы",
	"query_used_table" => "Запрос, использованный для создания этой таблицы",
	"query_used_view" => "Запрос, использованный для создания этого представления",
	"create_index2" => "Создать индекс для",
	"create_trigger2" => "Создать триггер",
	"new_fld" => "Добавление поля(ей) в таблицу '%s'",
	"add_flds" => "Добавить поля",
	"edit_col" => "Редактирование поля '%s'",
	"vac" => "Vacuum",
	"vac_desc" => "Большие базы данных иногда нуждаются в выполнении команды VACUUM для уменьшения объема временных данных на сервере. Нажмите кнопку ниже для применения VACUUM к базе данных '%s'.",
	"event" => "Событие",
	"each_row" => "Для Каждой Строки",
	"define_index" => "Определить параметры индекса",
	"dup_val" => "Дублированные значения",
	"allow" => "Разрешено",
	"not_allow" => "Не Разрешено",
	"asc" => "По возрастанию",
	"desc" => "По убыванию",
	"warn0" => "Вы были предупреждены.",
	"warn_passwd" => "Вы используете пароль по умолчанию, что не безопасно. Вы можете поменять его вверху %s.",
	#todo: translate
	"counting_skipped" => "Counting of records has been skipped for some tables because your database is comparably big and some tables don't have primary keys assigned to them so counting might be slow. Add a primary key to these tables or %sforce counting%s.",
	"sel_state" => "Выберите Определение",
	"delimit" => "Разделитель",
	"back_top" => "Вернуться Наверх",
	"choose_f" => "Выбрать Файл",
	"instead" => "Вместо",
	"define_in_col" => "Объявить индексное поле(я)",
	
	"delete_only_managed" => "Вы можете только удалять базы данных, управляемые этим инструментом!",
	"rename_only_managed" => "Вы можете только переименовывать базы данных, управляемые этим инструментом!",
	"db_moved_outside" => "Вы либо перенесли базу в директорию, где ей нельзя больше управлять, либо при проверке произошла ошибка из-за недостаточных прав.",
	"extension_not_allowed" => "Используемое вами расширение не поддерживается. Пожалуйста, используйте одно из перечисленных расширений",
	"add_allowed_extension" => "Вы можете добавить расширения в этот список, дополнив список \$allowed_extensions в конфигурации.",
	"directory_not_writable" => "Файл базы данных предоставляет права на запись, но директория, в которой он находится, должна также предоставлять права на запись. SQLite хранит в ней временные файлы.",
	"tbl_inexistent" => "Таблица %s не существует",

	// errors that can happen when ALTER TABLE fails. You don't necessarily have to translate these.
	"alter_failed" => "Изменение Таблицы %s не удалось",
	"alter_tbl_name_not_replacable" => "нельзя заменить имя таблицы временным",
	"alter_no_def" => "нет ALTER определения",
	"alter_parse_failed" =>"не удалось распарсить ALTER определение",
	"alter_action_not_recognized" => "ALTER действие не может быть распознано",
	"alter_no_add_col" => "не обнаружено столбцов для добавления в определении ALTER",
	"alter_pattern_mismatch"=>"Шаблон не соответствует вашему определению CREATE TABLE",
	"alter_col_not_recognized" => "невозможно распознать новое или старое имя столбца",
	"alter_unknown_operation" => "Неизвестная операция ALTER!",
	
	/* Help documentation */
	"help_doc" => "Документация",
	"help1" => "Библиотеки расширения SQLite",
	"help1_x" => "%s использует PHP библиотеки расширения, которые позволяют взаимодействие с базами данных SQLite. В настоящий момент, %s поддерживает PDO, SQLite3 и SQLiteDatabase. PDO и SQLite3 работают с SQLite версии 3, SQLiteDatabase с версией 2. Т.о., если ваша сборка PHP содержит несколько библиотек расширения для SQLite, PDO и SQLite3 будут иметь приоритет, как лучшие технологии. Тем не менее, если существующие базы данных SQLite версии 2, %s придется использовать SQLiteDatabase только для этих баз. Не все базы данных должны быть одной версии. При создании базы, будет использовано самое совершенное расширение.",
	"help2" => "Создание новой базы данных",
	"help2_x" => "Когда вы создаете новую базу данных, введенное вами имя будет дополнено соответствующим расширением файла (.db, .db3, .sqlite, и т.д.) если вы не ввели его сами. База данных будет создана в директории, указанной в переменной \$directory.",
	"help3" => "Таблицы и Представления(VIEW)",
	"help3_x" => "На главной странице базы данных есть список Таблиц и Представлений. Т.к. Представления доступны только для чтения, некоторые функции будут недоступны. Если вы хотите изменить данные Представления, вам нужно его удалить и создать новое с подходящим определением SELECT, которое запросит другие существующие таблицы. Больше информации вы можете получить здесь: <a href='http://ru.wikipedia.org/wiki/%D0%9F%D1%80%D0%B5%D0%B4%D1%81%D1%82%D0%B0%D0%B2%D0%BB%D0%B5%D0%BD%D0%B8%D0%B5_(%D0%B1%D0%B0%D0%B7%D1%8B_%D0%B4%D0%B0%D0%BD%D0%BD%D1%8B%D1%85)' target='_blank'>http://ru.wikipedia.org/wiki/%D0%9F%D1%80%D0%B5%D0%B4%D1%81%D1%82%D0%B0%D0%B2%D0%BB%D0%B5%D0%BD%D0%B8%D0%B5_(%D0%B1%D0%B0%D0%B7%D1%8B_%D0%B4%D0%B0%D0%BD%D0%BD%D1%8B%D1%85)</a>",
	"help4" => "Написание Select для нового Представления",
	"help4_x" => "Когда вы создаете новое представление, вы должны написать определение SQL SELECT, результат которого будет являться данными Представления. Представление - это простая таблица только для чтения, к которой можно сделать запрос как к обычной таблице, за исключением запросов, добавляющих или изменяющих строки или столбцы. Представление используется для удобного доступа к данным.",
	"help5" => "Экспорт структуры в SQL Файл",
	"help5_x" => "Во время процесса экспортирования в SQL файл, вы можете выбрать вставку запросов, которые создадут таблицы или столбцы.",
	"help6" => "Экспорт данных в SQL Файл",
	"help6_x" => "Во время процесса экспортирования в SQL файл, вы можете выбрать вставку запросов, которые заполнят таблицы текущими записями таблиц.",
	"help7" => "Добавление DROP TABLE в экспортируемый SQL Файл",
	"help7_x" => "Во время процесса экспортирования в SQL файл, вы можете выбрать вставку запросов, которые удалят существующие таблицы перед созданием для избежания ошибки \"Таблица уже существует\".",
	"help8" => "Добавление Транзакции в экспортируемый SQL Файл",
	"help8_x" => "Во время процесса экспортирования в SQL файл, вы можете выбрать вставку запросов в TRANSACTION, т.о. если во время импортирования файла случится ошибка, база данных вернется в предыдущее состояние, предотвращая частичное изменение данных.",
	"help9" => "Добавление Комментариев в экспортируемый SQL Файл",
	"help9_x" => "Во время процесса экспортирования в SQL файл, вы можете выбрать вставку комментариев, которые объясняют каждый шаг, помогая лучше понимать процесс человеку, читающему файл."
	
	);
?>
