<?php
// Arabic language file by Ayman Teryaki (teryaki1963)
// Read our wiki on how to translate: https://bitbucket.org/phpliteadmin/public/wiki/Localization
$lang = array(
	"direction" => "RTL",
	"date_format" => '\a\m d.m.Y \u\m H:i:s (T)',
	"ver" => "رقم النسخة",
	"for" => "ل",
	"to" => "في",
	"go" => "بدأ",
	"yes" => "نعم",
	"no" => "لا",
	"sql" => "أس-كيو-لايت",
	"csv" => "سي-أس-في",
	"csv_tbl" => "الجدول الخاص لملف CSV",
	"srch" => "إبحث",
	"srch_again" => "البحث من جديد",
	"login" => "تسجيل الدخول",
	"logout" => "تسجيل الخروج",
	"view" => "عرض",
	"confirm" => "نعم متأكد",
	"cancel" => "إلغاء",
	"save_as" => "حفظ",
	"options" => "خيارات",
	"no_opt" => "لا يوجد خيارات",
	"help" => "مساعد",
	"installed" => "تم الحفظ",
	"not_installed" => "لم يتم الحفظ",
	"done" => "تم",
	"insert" => "إضافة",
	"export" => "إصدار",
	"import" => "إستيراد",
	"rename" => "تغيير الإسم",
	"empty" => "إفراغ",
	"drop" => "محي",
	"tbl" => "جدول",
	"chart" => "رسم بياني",
	"err" => "خطأ",
	"act" => "العملية",
	"rec" => "البيانات",
	"col" => "عمود",
	"cols" => "عواميد",
	"rows" => "سطر/سطور",
	"edit" => "تغيير",
	"del" => "محي",
	"add" => "إضافة",
	"backup" => "حفظ ملف بنك المعلومات",
	"before" => "قبلها",
	"after" => "بعدها",
	"passwd" => "كلمة السر",
	"passwd_incorrect" => "كلمة السر غير صحيحة.",
	"chk_ext" => "تحقق إن كانت نسخة بي-أتش-بي لديك تعمل بها أس-كيو-لايت",
	"autoincrement" => "ترتيب تسلسلى",
	"not_null" => "غير فارغة",
	"none" => "None",   #todo: translate
	"as_defined" => "As defined",  #todo: translate
	"expression" => "Expression",  #todo: translate
	
	"sqlite_ext" => "إضافة ل أس-كيو-لايت",
	"sqlite_ext_support" => "يبدو أن نسخة بي-أتش-بي لديك ليست مهيئة لإضافات أس-كيو-لايت. لا تقدر إستخدام %s من قبل تركيب هذه الإضافات.",
	"sqlite_v" => "رقم نسخة أش-كيو-لايت",
	"sqlite_v3_error" => "يبدوا أن بنك المعلومات لديك مبني على نسخة أس-كيو-لايت رقم 2 ولكن بي-أتش-بي ليس لديه هذه الإضافة. لحل هذه المشكلة إما أن تمحي بنك المعلومات وتبدأ ب %s من جديد أو تضع بنك معلومات للنسخة 2 بنفسك.",
	"sqlite_v2_error" => "يبدوا أن بنك المعلومات لديك مبني على نسخة أس-كيو-لايت رقم 3 ولكن بي-أتش-بي ليس لديه هذه الإضافة. لحل هذه المشكلة إما أن تمحي بنك المعلومات وتبدأ ب %s من جديد أو تضع بنك معلومات للنسخة 3 بنفسك.",
	"report_issue" => "لم نستطيع تحديد المشكلة, لهذا نرجوا أن تبعثوا لنا توضيح لها ",
	"sqlite_limit" => "بسبب التقييدات الناتجة من أس-كيو-لايت لا تستطيع التغيير إلا إسم الحقل أو نوع المعلومات.",
	
	"php_v" => "نسخة بي-أتش-بي",
	
	"db_dump" => "إستيداع بنك المعلومات",
	"db_f" => "ملف بنك المعلومات",
	"db_ch" => "بنك معلومات آخر",
	"db_event" => "حدث بنك المعلومات",
	"db_name" => "إسم ينك المعلومات",
	"db_rename" => "تغيير إسم بنك المعلومات",
	"db_renamed" => "بنك المعلومات '%s' تم تغيير إسمه ل",
	"db_del" => "محي بنك المعلومات",
	"db_path" => "المسار لبنك المعلومات",
	"db_size" => "حجم بنك المعلومات",
	"db_mod" => "آخر مرة تم تغيير بنك المعلومات",
	"db_create" => "وضع بنك معلومات جديد",
	"db_vac" => "بنك المعلومات '%s' تم تحجيمه.",
	"db_not_writeable" => "بنك المعلومات '%s' غير موجود ولا نستطيع تركيبه لأن مكان التخزين '%s' لا يسمح بهذا. لإمكانية الإستخدام يجب إعطاء السماح لمكان التخزين.",
	"db_setup" => "هناك مشكلة في تركيب بنك المعلومات %s وسنحاول البحث عنها حتى تتمكن من حلها",
	"db_exists" => "هناك بنك معلومات آخر بنفس الإسم '%s'.",
	
	"exp_on" => "تم التصدير في تاريخ",
	"struct" => "الهيكل",
	"struct_for" => "هيكل ل",
	"on_tbl" => "للجدول",
	"data_dump" => "إستيداع المعلومات ل",
	"backup_hint" => "نصائح: لتأمين بنك المعلومات, أسهل طريقة هي %s.",
	"backup_hint_linktext" => "تأمين ملف بنك المعلومات",
	"total_rows" => "المجمل: %s سطور",
	"total" => "المجمل",
	"not_dir" => "مكان التخزين الذي أعطيتنا إيه لنبحث به عن بنوك المعلومات غير موجود .",
	"bad_php_directive" => "يبدوا أن 'register_globals' في نسخة بي-أنش-بي لديك نشطة. وهذا الأمر بشكل خطورة. من الأفضل إقفال هذا الخيار من قبل أن تكمل.",
	"page_gen" => "بنيت الصفحة في خلال %s ثواني.",
	"powered" => "تمت البرمجة من:",
	"remember" => "البقاء مسجل",
	"no_db" => "مرحبا بكم في phpLiteAdmin. يبدوا أنك وضعت مكان خاص لملفات بنوك المعلومات. ولكننا لم نجد أي بنك معلومات في هذا المكان. بإمكانك تعبأة الطلب التالى لتضع بنك معلومات جديد.",
	"no_db2" => "المكان الذي إخترته لبنك المعلومات لا يحتوي على هذا الملف ولا يمكننا أن نكتب به شيئا. ولهذا السبب لم نستطيع وضع ملف جديد في هذا المكان. إما أن تعطي السماحية لهذا المكان للكتابة به أو تضع أنت الملف بنفسك به.",
	
	"create" => "وضع",
	"created" => "تم وضعه",
	"create_tbl" => "وضع جدول جديد",
	"create_tbl_db" => "وضع جدول جديد في بنك المعلومات",
	"create_trigger" => "وضع مؤثر جديد على الجدول",
	"create_index" => "وضع فهرس جديد على الجدول",
	"create_index1" => "ضع فهرس",
	"create_view" => "ضع عرض جديد على بنك المعلومات",
	
	"trigger" => "مؤثر",
	"triggers" => "مؤثرات",
	"trigger_name" => "إسم المؤثر",
	"trigger_act" => "عملية المؤثر",
	"trigger_step" => "خطواط المؤثر (منفصلة عبر علامة الوقف)",
	"when_exp" => "التعبير WHEN (كتابة التعبير دون 'WHEN')",
	"index" => "فهرس",
	"indexes" => "فهارس",
	"index_name" => "إسم الفهرس",
	"name" => "الإسم",
	"unique" => "مميزة",
	"seq_no" => "الرقم التسلسلي",
	"emptied" => "تم الإفراغ",
	"dropped" => "تم المحي",
	"renamed" => "تم تغيير الإسم ل",
	"altered" => "تم التغيير بنجاح",
	"inserted" => "تم الإدماج",
	"deleted" => "تم المحي",
	"affected" => "معني",
	"blank_index" => "لا تستطيع ترك إسم الفهرس فارغ.",
	"one_index" => "يجب أن تحدد على الأقل عامود واحد للفهرس.",
	"docu" => "شروحات",
	"license" => "رخصة",
	"proj_site" => "صفحة المشروع",
	"bug_report" => "ربما هناك خطأ من البرنامج ومن الممكن التبليغ عنه على صفحتنا:",
	"return" => "رجوع",
	"browse" => "عرض",
	"fld" => "الحقل",
	"fld_num" => "عدد الحقول",
	"fields" => "الحقول",
	"type" => "النوع",
	"operator" => "العامل",
	"val" => "القيمة",
	"update" => "تحديث",
	"comments" => "تعليقات",
	
	"specify_fields" => "يجب تحديد عدد الحقول للجدول.",
	"specify_tbl" => "يجب تحديد إسم الجدول.",
	"specify_col" => "يجب تحديد إسم العامود.",
	
	"tbl_exists" => "يتضح أن هناك جدول بنفس الإسم.",
	"show" => "عرض",
	"show_rows" => "عرض %s سطور. ",
	"showing" => "عرض",
	"showing_rows" => "عرض السطور",
	"query_time" => "(العملية إحتاجت %s ثواني)",
	"syntax_err" => "هناك مشكلة بالتعبير الذي كتبته (العملية لم تنجح)",
	"run_sql" => "نفذ أمر أس-كيو-أل التالي في بنك المعلومات هذا: '%s'",
	
	"ques_empty" => "هل أنت متأكد من إفراغ جدول '%s' ؟",        
	"ques_drop" => "هل أنت متأكد من محي جدول '%s' ؟",
	"ques_drop_view" => "هل أنت متأكد من محي عرض '%s' ؟",
	"ques_del_rows" => "هل أنت متأكد من محي السطر/السطور %s من جدول '%s' ؟",
	"ques_del_db" => "هل أنت متأكد من محي بنك المعلومات '%s' ؟",
	"ques_column_delete" => "هل أنت متأكد من محي العامود/العواميج %s من جدول '%s' ؟",
	"ques_del_index" => "هل أنت متأكد من محي الفهرس '%s' ؟",
	"ques_del_trigger" => "هل أنت متأكد من محي المؤثر '%s' ؟",
	#todo: translate
	"ques_primarykey_add" => "Are you sure you want to add a primary key for the column(s) %s in table '%s'?",

	"export_struct" => "تصدير مع الهيكل",
	"export_data" => "تصدير مع كافة المعلومات",
	"add_drop" => "أضف التعبير DROP TABLE (محي الجدول)",
	"add_transact" => "أضف التعبير TRANSACTION (عملية متبادلة)",
	"fld_terminated" => "فصل الحقول عبر",
	"fld_enclosed" => "إحاطة الحقول ب",
	"fld_escaped" => "علامة Escape",
	"fld_names" => "أسماء الحقول في السطر الأول",
	"rep_null" => "تبديل NULL ب",
	"rem_crlf" => "إبعاد جميع الخطوط الفاصلة من الحقول",
	"put_fld" => "ضع أسماء الحقول في السطر الأول",
	"null_represent" => "NULL ممثلة عبر",
	"import_suc" => "لقد تم التصدير بنجاح.",
	"import_into" => "التصدير إلى",
	"import_f" => "إختيار الملف للتصدير",
	"rename_tbl" => "تغيير إسم جدول '%s' ل",
	
	"rows_records" => "تبدأ السطور من البيان رقم: ",
	"rows_aff" => "السطور المعنية",
	
	"as_a" => "ك",
	"readonly_tbl" => "'%s' هي فقط عرض, هذا يعني أن التعبير SELECT يتعامل مع الجدول للقرأة فقط وليس للتغيير. لهذا لا تستطيع إضافة أو تغيير أي معلومة.",
	"chk_all" => "علم الجميع",
	"unchk_all" => "إزاحة جميع العلامات",
	"with_sel" => "المعلمات فقط",
	
	"no_tbl" => "ليس هناك أي جدول في بنك المعلومات هذا.",
	"no_chart" => "إذا كنت تقرأ هذه الجملة فهذا معناه أننا لم نستطيع عمل رسم البيانات. ربما تكون المعلومات المدلاة غير مناسبة لوضع رسم بيانات لها.",
	"no_rows" => "لم نجد سطور في المكان المحدد للجدول.",
	"no_sel" => "لم تقم بإختيار أي شيئ.",
	
	"chart_type" => "نوع الرسم البياني",
	"chart_bar" => "رسم بياني عامودي",
	"chart_pie" => "رسم بياني دائري",
	"chart_line" => "رسم بياني خطوط",
	"lbl" => "العنوان",
	"empty_tbl" => "هذا الجدول فارغ.",
	"click" => "أنقر هنا",
	"insert_rows" => "لإضافة سطور جديدة.",
	"restart_insert" => "إبدأ الإضافة من جديد ب ",
	"ignore" => "تجاهل",
	"func" => "العملية",
	"new_insert" => "أضف كسطر جديد",
	"save_ch" => "تخزين التغيرات",
	"def_val" => "القيمة الإعتيادية",
	"prim_key" => "المفتاح الأولي",
	"tbl_end" => "إضافة حقل أو حقول في آخر هذا الجدول",
	"query_used_table" => "التعبير الذي إحتجنا له لوضع هذا الجدول هي:",
	"query_used_view" => "التعبير الذي وضع به هذا العرض",
	"create_index2" => "وضع فهرس على",
	"create_trigger2" => "وضع مؤثر جديد",
	"new_fld" => "أضف حقول جديدة للجدول '%s' ",
	"add_flds" => "أضف حقول",
	"edit_col" => "تحرير العامود '%s'",
	"vac" => "تحجبم",
	"vac_desc" => "من وقت لآخر يجب تصغير حجم بنك المعلومات لكي لا يزداد من عبر المعلومات الفائضة. إضغظ على الزر التالي لكي تقوم بتحجيم بنك المعلومات: '%s'",
	"event" => "الحدث",
	"each_row" => "لكل سطر",
	"define_index" => "إعطاء نوعية الفهرس",
	"dup_val" => "إستنساخ",
	"allow" => "مقبول",
	"not_allow" => "غير مقبول",
	"asc" => "من الأسفل للأعلى",
	"desc" => "من الأعلى للأسفل",
	"warn0" => "لقد قمنا بتحزيرك.",
	"warn_passwd" => "إنك تستخدم كلمة السر المعروفة وهذا يشكل خطر على بنك المعلومات. بإمكانك تغيير كلمة السر بسهولة في المكان الأعلى من ملف %s .",
	#todo: translate
	"counting_skipped" => "Counting of records has been skipped for some tables because your database is comparably big and some tables don't have primary keys assigned to them so counting might be slow. Add a primary key to these tables or %sforce counting%s.",
	"sel_state" => "التعبير: Select",
	"delimit" => "تقسيم الأمر عبر هذه العلامة",
	"back_top" => "إلى البداية",
	"choose_f" => "إختيار الملف",
	"instead" => "عوضا عن",
	"define_in_col" => "قم بإختيار عامود الفهرس أو الفهارس",

	"delete_only_managed" => "لا نستطيع محي بنوك المعلومات إلا التي وضعت بهذا البرنامج!",
	"rename_only_managed" => "لا نستطيع تغيير إسم بنوك المعلومات إلا التي وضعت بهذا البرنامج!",
	"db_moved_outside" => "ربما قد وضعت ملف بنك المعلومات في مكان آخر, حيث أننا لا نستطيع التعامل معه أو أن عملية التحقق منه لم تنجح بسبب إنعدام الصلاحية المفروضة.",
	"extension_not_allowed" => "الإضاف الخاصة بالملفات لا توجد في لائحة الملفات المسموحة. الرجاء إستخدام إضافة الملفات التالية",
	"add_allowed_extension" => "بإمكانك وضع إضافة الملفات المختارة في لائحة الملفات المسموحة عن طريق كتابة المصطلح  \$allowed_extensions في مكان المكونات.",
	"directory_not_writable" => "قد أستطيع الكتابة في ملف بنك المعلومات ولكن يبدوا أن المكان الذي يوجد به الملف ليس لديه الصلاحية للكتابة به. لهذا يجب إعطاء الصلاحية للمكان أيضا لأن برنامج أس-كيو-لابت يحاول أن يضع ملف جديد من قبل التخزين.",
	"tbl_inexistent" => "لا يوجد جدول بإسم %s ",

	// errors that can happen when ALTER TABLE fails. You don't necessarily have to translate these.
	"alter_failed" => "لم ننجح بتغيير الجدول %s ",
	"alter_tbl_name_not_replacable" => "لم ننجح بتغيير إسم الجدول",
	"alter_no_def" => "لا يوجد تعبير خاص للتغيير",
	"alter_parse_failed" =>"عملية التحليل لتعبير ALTER لم تنجح",
	"alter_action_not_recognized" => "لم نقدر بالتعرف على عملية التغيير",
	"alter_no_add_col" => "لم نستطيع التعرف على أي عامود وضعته من خلال التعبير (تغيير)",
	"alter_pattern_mismatch"=>"التعبير CREATE TABLE لا يتناسب مع الشكل الحالي",
	"alter_col_not_recognized" => "لم نقدر بالتعرف على أي سطور جديدة أو قديمة",
	"alter_unknown_operation" => "عملية تغيير غير معروفة!",
	
	/* Help documentation */
	"help_doc" => "وثائق مساعدة",
	"help1" => "مكتبة الأضافات ل أس-كيو-لايت",
	"help1_x" => "برنامج phpLiteAdmin يستخدم إضافات بي-أتش-بي التي تسمح بالتعامل مع بنوك المعلومات ل أس-كيو-لايت. في الوقت الحالي phpLiteAdmin يدعم PDO, SQLite3 و SQLiteDatabase. أما PDO و SQLite3 فهم بحاجة لنسخة أس-كيو-لايت رقم 3 و SQLiteDatabase بحاجة فقط للنسخة رقم 2. في حال برنامج بي-أتش-بي لديه أكثر من إضافة واحدة ل أس-كيو-لايت فالأفضل إستخدام PDO و SQLite3 حتى نتمكن من إستغلال الفوائد منهم. وفي حال يوجد عندك بنك معلومات للنسخة رقم 2 فسيتعامل phpLiteAdmin معها بشكل تلقائي. ليس من الضروري أن تكون جميع بنوك المعلومات نفس رقم النسخة. لوضع ملف جديد من الأفضل إستخدام أحدث نسخة متواجدة.",
	"help2" => "وضع بنك معلومات جديد",
	"help2_x" => "عندما تضع بنك معلومات جديد فنحن سنقوم بتخزين الملف بهذه النوعية (.db, .db3, .sqlite, الخ.) في حال لم تحدد النوعية بنفسك. وبنك المعلومات الجديد سيتم تخزينه  في المكان المدرج في المتغير \$directory .",
	"help3" => "جدول أم عرض",
	"help3_x" => "On the main database page, there is a list of tables and views. Since views are read-only, certain operations will be disabled. These disabled operations will be apparent by their omission in the location where they should appear on the row for a view. If you want to change the data for a view, you need to drop that view and create a new view with the appropriate SELECT statement that queries other existing tables. For more information, see <a href='http://en.wikipedia.org/wiki/View_(database)' target='_blank'>http://en.wikipedia.org/wiki/View_(database)</a>",
	"help4" => "أكتب التعبير SELECT لعرض جديد",
	"help4_x" => "When you create a new view, you must write an SQL SELECT statement that it will use as its data. A view is simply a read-only table that can be accessed and queried like a regular table, except it cannot be modified through insertion, column editing, or row editing. It is only used for conveniently fetching data.",
	"help5" => "صدر الهيكل في ملف أس-كيو-أل",
	"help5_x" => "During the process for exporting to an SQL file, you may choose to include the queries that create the table and columns.",
	"help6" => "تصدير المعلومات في ملف أس-كيو-أل",
	"help6_x" => "During the process for exporting to an SQL file, you may choose to include the queries that populate the table(s) with the current records of the table(s).",
	"help7" => "أضف التعبير DROP TABLE للملف المصدر",
	"help7_x" => "During the process for exporting to an SQL file, you may choose to include queries to DROP the existing tables before adding them so that problems do not occur when trying to create tables that already exist.",
	"help8" => "أضف التعبير TRANSACTION للملف المصدر",
	"help8_x" => "During the process for exporting to an SQL file, you may choose to wrap the queries around a TRANSACTION so that if an error occurs at any time during the importation process using the exported file, the database can be reverted to its previous state, preventing partially updated data from populating the database.",
	"help9" => "أضف التعليقات للملف المصدر",
	"help9_x" => "During the process for exporting to an SQL file, you may choose to include comments that explain each step of the process so that a human can better understand what is happening."
);
