<?php
// Chinese language-texts for phpLiteAdmin
// Read our wiki on how to translate: https://bitbucket.org/phpliteadmin/public/wiki/Localization
$lang = array(
	"direction" => "LTR",
	"date_format" => 'Y/m/d H:i:s',  // see http://php.net/manual/en/function.date.php for what the letters stand for
	"ver" => "版本",
	"for" => "for",
	"to" => "to",
	"go" => "转到",
	"yes" => "Yes",
	"sql" => "SQL",
	"csv" => "CSV",
	"csv_tbl" => "和CSV关联的表为",
	"srch" => "搜索",
	"srch_again" => "再次搜索",
	"login" => "登录",
	"logout" => "登出",
	"view" => "View",
	"confirm" => "确认",
	"cancel" => "取消",
	"save_as" => "另存为",
	"options" => "选项",
	"no_opt" => "无选项",
	"help" => "帮助",
	"installed" => "installed",
	"not_installed" => "not installed",
	"done" => "done",
	"insert" => "插入",
	"export" => "导出",
	"import" => "导入",
	"rename" => "改名",
	"empty" => "清空",
	"drop" => "删除",
	"tbl" => "表",
	"chart" => "Chart",
	"err" => "错误",
	"act" => "动作",
	"rec" => "记录数",
	"col" => "列",
	"cols" => "列",
	"rows" => "行",
	"edit" => "修改",
	"del" => "删除",
	"add" => "添加",
	"backup" => "备份数据库文件",
	"before" => "之前",
	"after" => "之后",
	"passwd" => "输入密码",
	"passwd_incorrect" => "密码错误.",
	"chk_ext" => "正在检查支持SQLite的PHP扩展",
	"autoincrement" => "自动增量",
	"not_null" => "非NULL",
	"attention" => "Attention",
	"none" => "None",   #todo: translate
	"as_defined" => "As defined",  #todo: translate
	"expression" => "Expression",  #todo: translate
	
	"sqlite_ext" => "SQLite扩展",
	"sqlite_ext_support" => "It appears that none of the supported SQLite library extensions are available in your installation of PHP. You may not use %s until you install at least one of them.",
	"sqlite_v" => "SQLite版本",
	"sqlite_v_error" => "It appears that your database is of SQLite version %s but your installation of PHP does not contain the necessary extensions to handle this version. To fix the problem, either delete the database and allow %s to create it automatically or recreate it manually as SQLite version %s.",
	"report_issue" => "The problem cannot be diagnosed properly. Please file an issue report at",
	"sqlite_limit" => "Due to the limitations of SQLite, only the field name and data type can be modified.",
	
	"php_v" => "PHP版本",
	
	"db_dump" => "数据库转储",
	"db_f" => "数据库文件",
	"db_ch" => "选择数据库",
	"db_event" => "数据库事件",
	"db_name" => "文件名",
	"db_rename" => "重命名数据库",
	"db_renamed" => "数据库 '%s' 的文件名已经修改为",
	"db_del" => "删除数据库",
	"db_path" => "路径",
	"db_size" => "文件大小",
	"db_mod" => "修改时间",
	"db_create" => "创建新数据库",
	"db_vac" => "数据库, '%s', 已经压缩[VACUUMed].",
	"db_not_writeable" => "数据库, '%s', 不存在并不能创建因为当前目录, '%s', 不可写. 除非使之可写否则程序不能使用.",
	"db_setup" => "设置数据库, %s 出现问题. 将尝试找出发生了什么事情, 这样你就可以更容易地解决这个问题",
	"db_exists" => "名称为 '%s' 的数据库, 文件或目录已存在.",
	
	"exported" => "导出",
	"struct" => "结构",
	"struct_for" => "结构",
	"on_tbl" => "在表",
	"data_dump" => "数据转储",
	"backup_hint" => "提示: 备份数据库的最简单方式是 %s.",
	"backup_hint_linktext" => "下载数据库文件",
	"total_rows" => "总 %s 行",
	"total" => "总数",
	"not_dir" => "您指定的目录扫描数据库不存在或不是一个目录。",
	"bad_php_directive" => "PHP指令，启用'register_globals的'。这是不好的。你需要禁用它，然后再继续。",
	"page_gen" => "页面呈现 %s 秒.",
	"powered" => "Powered by",
	"remember" => "记住我",
	"no_db" => "欢迎到 %s。似乎你已经选择好要扫描的目录数据库来管理。然而，%s 无法找到任何有效的SQLite数据库。您可以使用下面的表格来创建你的第一个数据库。",
	"no_db2" => "您指定的目录不包含任何现有的数据库管理，目录不可写。这意味着你不能用%s创建任何新的数据库。要么使目录可写或手动上传目录数据库。",
	
	"create" => "创建",
	"created" => "创建完毕",
	"create_tbl" => "创建新表",
	"create_tbl_db" => "在数据库中创建新表",
	"create_trigger" => "创建新触发器在表",
	"create_index" => "创建新索引在表",
	"create_index1" => "创建索引",
	"create_view" => "创建新视图",
	
	"trigger" => "触发器",
	"triggers" => "触发器",
	"trigger_name" => "触发器名称",
	"trigger_act" => "触发器动作",
	"trigger_step" => "触发器步骤[Trigger Steps] (分号终止)",
	"when_exp" => "WHEN 条件 (输入条件不包括 'WHEN')",
	"index" => "索引",
	"indexes" => "索引",
	"index_name" => "索引名",
	"name" => "名称",
	"unique" => "唯一值",
	"seq_no" => "序列号",
	"emptied" => "已被清空",
	"dropped" => "已被删除",
	"renamed" => "已被改名为",
	"altered" => "变更成功",
	"inserted" => "被插入",
	"deleted" => "被删除",
	"affected" => "被影响",
	"blank_index" => "索引名必须非空.",
	"one_index" => "必须至少指定一个索引列.",
	"docu" => "在线文档",
	"license" => "使用协议",
	"proj_site" => "官方网站",
	"bug_report" => "这或许是一个需要汇报的bug在",
	"return" => "返回",
	"browse" => "浏览",
	"fld" => "字段",
	"fld_num" => "表中字段数",
	"fields" => "字段",
	"type" => "类型",
	"operator" => "算符",
	"val" => "值",
	"update" => "更新",
	"comments" => "注释",
	
	"specify_fields" => "你必须指定表中的字段的数量。",
	"specify_tbl" => "你必须指定表名。",
	"specify_col" => "你必须指定一个列。",
	
	"tbl_exists" => "已存在同名表.",
	"show" => "显示",
	"show_rows" => "显示 %s 行. ",
	"showing" => "正在显示",
	"showing_rows" => "显示行",
	"query_time" => "(查询使用 %s 秒)",
	"syntax_err" => "你查询的语法有出现问题 (查询未被执行)",
	"run_sql" => "在数据库 '%s' 中执行查询",
	
	"ques_empty" => "你确定要清空表 '%s'?",
	"ques_drop" => "你确定要删除表 '%s'?",
	"ques_drop_view" => "你确定要删除视图 '%s'?",
	"ques_del_rows" => "你确定要删除行 %s 从表 '%s'?",
	"ques_del_db" => "你确定要删除数据库 '%s'?",
	"ques_column_delete" => "你确定要删除列 %s 从表 '%s'?",
	"ques_del_index" => "你确定要删除索引 '%s'?",
	"ques_del_trigger" => "你确定要删除触发器 '%s'?",
	#todo: translate
	"ques_primarykey_add" => "Are you sure you want to add a primary key for the column(s) %s in table '%s'?",
	
	"export_struct" => "导出结构",
	"export_data" => "导出数据",
	"add_drop" => "删除已存在表",
	"add_transact" => "添加实务",
	"fld_terminated" => "字段分隔符",
	"fld_enclosed" => "字段封闭符",
	"fld_escaped" => "字段转义符",
	"fld_names" => "字段名在第一行",
	"rep_null" => "替换NULL为",
	"rem_crlf" => "移除字段中的空字符CRLF",
	"put_fld" => "把字段名放在第一行",
	"null_represent" => "NULL描述为",
	"import_suc" => "导入成功.",
	"import_into" => "导入",
	"import_f" => "导入文件",
	"rename_tbl" => "表 '%s' 改名为",
	
	"rows_records" => "行, 开始于 # ",
	"rows_aff" => "row(s) affected. ",
	
	"as_a" => "as a",
	"readonly_tbl" => "'%s' 是一个视图, 意味着它是一个只能使用 SELECT 语句的只读表. 你不能修改或插入记录.",
	"chk_all" => "全选",
	"unchk_all" => "取消全选",
	"with_sel" => "选中项",
	
	"no_tbl" => "数据库中没有表",
	"no_chart" => "如果你可以看到这一点，就意味着不能生成图表。想查看你的数据可能不适合图表。",
	"no_rows" => "There are no rows in the table for the range you selected.",
	"no_sel" => "你什么都没选.",
	
	"chart_type" => "图表类型",
	"chart_bar" => "柱状图",
	"chart_pie" => "饼图",
	"chart_line" => "线图",
	"lbl" => "标签",
	"empty_tbl" => "表是空的.",
	"click" => "点这里",
	"insert_rows" => "来插入数据.",
	"restart_insert" => "重新插入 ",
	"ignore" => "忽略",
	"func" => "函数",
	"new_insert" => "插入新行",
	"save_ch" => "保存修改",
	"def_val" => "默认值",
	"prim_key" => "主键",
	"tbl_end" => "个新字段在表尾",
	"query_used_table" => "用于创建此表的查询",
	"query_used_view" => "用于创建视图的查询",
	"create_index2" => "创建新索引使用",
	"create_trigger2" => "创建新触发器",
	"new_fld" => "在表 '%s' 中添加新字段",
	"add_flds" => "Add Fields",
	"edit_col" => "修改列 '%s'",
	"vac" => "压缩[Vacuum]",
	"vac_desc" => "大型数据库有时需要在服务器上进行压缩. 点下面的按钮开始压缩[VACUUM]数据库 '%s'.",
	"event" => "事件",
	"each_row" => "在每行",
	"define_index" => "定义索引属性",
	"dup_val" => "重复值",
	"allow" => "允许",
	"not_allow" => "不允许",
	"asc" => "上升[ASC]",
	"desc" => "下降[DESC]",
	"warn0" => "你已经受到警告.",
	"warn_passwd" => "你正在使用默认的密码, 这比较危险的. 你可以很方便的在 %s 文件的中进行修改.",
	#todo: translate
	"counting_skipped" => "Counting of records has been skipped for some tables because your database is comparably big and some tables don't have primary keys assigned to them so counting might be slow. Add a primary key to these tables or %sforce counting%s.",
	"sel_state" => "选择语句",
	"delimit" => "分隔符",
	"back_top" => "回到上面",
	"choose_f" => "选择文件",
	"instead" => "替代",
	"define_in_col" => "定义索引列",
	
	"delete_only_managed" => "You can only delete databases managed by this tool!",
	"rename_only_managed" => "You can only rename databases managed by this tool!",
	"db_moved_outside" => "You either tried to move the database into a directory where it cannot be managed anylonger, or the check if you did this failed because of missing rights.",
	"extension_not_allowed" => "The extension you provided is not within the list of allowed extensions. Please use one of the following extensions",
	"add_allowed_extension" => "You can add extensions to this list by adding your extension to \$allowed_extensions in the configuration.",
	"directory_not_writable" => "The database-file itself is writable, but to write into it, the containing directory needs to be writable as well. This is because SQLite puts temporary files in there for locking.",
	"tbl_inexistent" => "Table %s does not exist",

	// errors that can happen when ALTER TABLE fails. You don't necessarily have to translate these.
	"alter_failed" => "Altering of Table %s failed",
	"alter_tbl_name_not_replacable" => "could not replace the table name with the temporary one",
	"alter_no_def" => "no ALTER definition",
	"alter_parse_failed" =>"failed to parse ALTER definition",
	"alter_action_not_recognized" => "ALTER action could not be recognized",
	"alter_no_add_col" => "no column to add detected in ALTER statement",
	"alter_pattern_mismatch"=>"Pattern did not match on your original CREATE TABLE statement",
	"alter_col_not_recognized" => "could not recognize new or old column name",
	"alter_unknown_operation" => "Unknown ALTER operation!",
	
	/* Help documentation */
	"help_doc" => "帮助文档",
	"help1" => "SQLite 库扩展",
	"help1_x" => "%s uses PHP library extensions that allow interaction with SQLite databases. Currently, %s supports PDO, SQLite3, and SQLiteDatabase. Both PDO and SQLite3 deal with version 3 of SQLite, while SQLiteDatabase deals with version 2. So, if your PHP installation includes more than one SQLite library extension, PDO and SQLite3 will take precedence to make use of the better technology. However, if you have existing databases that are of version 2 of SQLite, %s will be forced to use SQLiteDatabase for only those databases. Not all databases need to be of the same version. During the database creation, however, the most advanced extension will be used.",
	"help2" => "创建新数据库",
	"help2_x" => "When you create a new database, the name you entered will be appended with the appropriate file extension (.db, .db3, .sqlite, etc.) if you do not include it yourself. The database will be created in the directory you specified as the \$directory variable.",
	"help3" => "Tables vs. Views",
	"help3_x" => "On the main database page, there is a list of tables and views. Since views are read-only, certain operations will be disabled. These disabled operations will be apparent by their omission in the location where they should appear on the row for a view. If you want to change the data for a view, you need to drop that view and create a new view with the appropriate SELECT statement that queries other existing tables. For more information, see <a href='http://en.wikipedia.org/wiki/View_(database)' target='_blank'>http://en.wikipedia.org/wiki/View_(database)</a>",
	"help4" => "Writing a Select Statement for a New View",
	"help4_x" => "When you create a new view, you must write an SQL SELECT statement that it will use as its data. A view is simply a read-only table that can be accessed and queried like a regular table, except it cannot be modified through insertion, column editing, or row editing. It is only used for conveniently fetching data.",
	"help5" => "Export Structure to SQL File",
	"help5_x" => "During the process for exporting to an SQL file, you may choose to include the queries that create the table and columns.",
	"help6" => "Export Data to SQL File",
	"help6_x" => "During the process for exporting to an SQL file, you may choose to include the queries that populate the table(s) with the current records of the table(s).",
	"help7" => "Add Drop Table to Exported SQL File",
	"help7_x" => "During the process for exporting to an SQL file, you may choose to include queries to DROP the existing tables before adding them so that problems do not occur when trying to create tables that already exist.",
	"help8" => "Add Transaction to Exported SQL File",
	"help8_x" => "During the process for exporting to an SQL file, you may choose to wrap the queries around a TRANSACTION so that if an error occurs at any time during the importation process using the exported file, the database can be reverted to its previous state, preventing partially updated data from populating the database.",
	"help9" => "Add Comments to Exported SQL File",
	"help9_x" => "During the process for exporting to an SQL file, you may choose to include comments that explain each step of the process so that a human can better understand what is happening."
	
	);
?>