/* overall styles for entire page */
body {
	margin: 0px;
	padding: 0px;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 14px;
	color: #000000;
	background-color: #e0ebf6;
	overflow:auto;
}
.body_tbl td{ padding:9px 2px 9px 9px; }
.left_td{ width:100px; }

/* general styles for hyperlink */
a { color: #03F; text-decoration: none; cursor :pointer; }
a:hover { color: #06F; }
hr {
	height: 1px;
	border: 0;
	color: #bbb;
	background-color: #bbb;
	width: 100%;	
}
/* logo text containing name of project */
h1 {
	margin: 0px;
	padding: 5px;
	font-size: 24px;
	background-color: #f3cece;
	text-align: center;
	color: #000;
	border-top-left-radius:5px;
	border-top-right-radius:5px;
	-moz-border-radius-topleft:5px;
	-moz-border-radius-topright:5px;
}
/* the div container for the links */
#headerlinks {
	text-align:center;
	margin-bottom:10px;
	padding:5px 15px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	border-left-style:none;
	border-right-style:none;
	font-size:12px;
	background-color:#e0ebf6;
	font-weight:bold;
}
/* version text within the logo */
h1 #version { color: #000000; font-size: 16px; }
/* logo text within logo */
h1 #logo { color:#000; }
/* general header for various views */
h2 {
	margin:0px;
	padding:0px;
	font-size:14px;
	margin-bottom:20px;
}
/* input buttons and areas for entering text */
input, select, textarea, .CodeMirror {
	font-family:Arial, Helvetica, sans-serif;
	background-color:#eaeaea;
	color:#03F;
	border-color:#03F;
	border-style:solid;
	border-width:1px;
	margin:5px;
	border-radius:5px;
	-moz-border-radius:5px;
	padding:3px;
}
/* just input buttons */
input.btn { cursor:pointer; }
input.btn:hover { background-color:#ccc; }
/* form label */
fieldset label {
	min-width: 200px;
	display: block;
	float: left;
}
/* general styles for hyperlink */
fieldset {
	padding:15px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	border-radius:5px;
	-moz-border-radius:5px;
	background-color:#f9f9f9;
}
/* outer div that holds everything */
#container { padding:10px; }
/* div of left box with log, list of databases, etc. */
#leftNav {
	min-width:250px;
	padding:0px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	background-color:#FFF;
	padding-bottom:15px;
	border-radius:5px;
	-moz-border-radius:5px;
}
/* the database select list / select box */
.databaseList select {
	max-width: 200px;
}
/* The table that hold left */
.viewTable tr td{ padding:1px; }
/* div holding the login fields */
#loginBox {
	width:500px;
	margin-left:auto;
	margin-right:auto;
	margin-top:50px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	background-color:#FFF;
	border-radius:5px;
	-moz-border-radius:5px;
}
/* div under tabs with tab-specific content */
#main {
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	padding:15px;
	background-color:#FFF;
	border-bottom-left-radius:5px;
	border-bottom-right-radius:5px;
	border-top-right-radius:5px;
	-moz-border-radius-bottomleft:5px;
	-moz-border-radius-bottomright:5px;
	-moz-border-radius-topright:5px;
}
/* odd-numbered table rows */
.td1 {
	background-color:#f9e3e3;
	text-align:right;
	font-size:12px;
	padding-left:10px;
	padding-right:10px;
}
/* even-numbered table rows */
.td2 {
	background-color:#f3cece;
	text-align:right;
	font-size:12px;
	padding-left:10px;
	padding-right:10px;
}
/* table column headers */
.tdheader {
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	font-weight:bold;
	font-size:12px;
	padding-left:10px;
	padding-right:10px;
	background-color:#e0ebf6;
	border-radius:5px;
	-moz-border-radius:5px;
}
/* div holding the confirmation text of certain actions */
.confirm {
	border-color:#03F;
	border-width:1px;
	border-style:dashed;
	padding:15px;
	background-color:#e0ebf6;
}
/* tab navigation for each table */
.tab {
	display:block;
	padding:5px;
	padding-right:8px;
	padding-left:8px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	margin-right:5px;
	float:left;
	border-bottom-style:none;
	position:relative;
	top:1px;
	padding-bottom:4px;
	background-color:#eaeaea;
	border-top-left-radius:5px;
	border-top-right-radius:5px;
	-moz-border-radius-topleft:5px;
	-moz-border-radius-topright:5px;
}
/* pressed state of tab */
.tab_pressed {
	display:block;
	padding:5px;
	padding-right:8px;
	padding-left:8px;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	margin-right:5px;
	float:left;
	border-bottom-style:none;
	position:relative;
	top:1px;
	background-color:#FFF;
	cursor:default;
	border-top-left-radius:5px;
	border-top-right-radius:5px;
	-moz-border-radius-topleft:5px;
	-moz-border-radius-topright:5px;
}
/* help section */
.helpq { font-size:11px; font-weight:normal; }
#help_container {
	padding:0px;
	font-size:12px;
	margin-left:auto;
	margin-right:auto;
	background-color:#ffffff;
}
.help_outer {
	background-color:#FFF;
	padding:0px;
	height:300px;
	
	position:relative;
}
.help_list { padding:10px; height:auto; }

.headd {
	font-size:14px;
	font-weight:bold;	
	display:block;
	padding:10px;
	background-color:#e0ebf6;
	border-color:#03F;
	border-width:1px;
	border-style:solid;
	border-left-style:none;
	border-right-style:none;
}
.help_inner { padding:10px;	}
.help_top {
	display:block;
	position:absolute;
	right:10px;
	bottom:10px;	
}
.warning, .delete, .empty, .drop, .delete_db { color:red; }
.sidebar_table { font-size:11px; }
.active_table, .active_db { text-decoration:underline; }
.null { color:#888; }
.found { background:#FFFF00; text-decoration:none; }
