/*
phpLiteAdmin Theme
Created by Sanne Foltz on 8/1/12
*/

/* overall styles for entire page */
* {
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
}

body
{
	margin: 0px;
	padding: 0px;
	font-family: Helvetica, Arial, sans-serif;
	font-size: 14px;
	line-height: 1.4;
	color: #000000;
	background-color: #f7f7f7;
}
/* general styles for hyperlink */
a
{
	color: #2771AA;
	text-decoration: none;
	cursor :pointer;
}
a:hover
{
	color: #003A66;
	text-decoration: underline;
}
/* horizontal rule */
hr
{
	height: 1px;
	border: 0;
	color: #bbb;
	background-color: #bbb;
	width: 100%;
}
/* logo text containing name of project */
h1
{
	margin: 0px;
	padding: 5px;
	font-size: 18px;
	background-color: #eee;
	text-align: center;
	margin-bottom: 10px;
	color: #000;
	border-top-left-radius:3px;
	border-top-right-radius:3px;

}
/* version text within the logo */
h1 #version
{
	color: #333;
	font-size: 14px;
}
/* logo text within logo */
h1 #logo
{
	color:#333;

}
/* general header for various views */
h2
{
	margin:0px;
	padding:0px;
	font-size:14px;
	margin-bottom:20px;
}
/* input buttons and areas for entering text */
input[type="text"], textarea
{
	background-color:white;
	color:black;
	border-color:#ccc;
	border-style:solid;
	border-width:1px;
	margin:3px 0;
	border-radius:2px;
	padding:4px;
	font-size:14px;
	font-family:monospace;
	width:100%;
}
textarea{
	height:4em;
}
select{
	font-size: 14px;


}
.btn,
.btn:visited {
	width: auto;
	padding: 0.4em 0.8em;
	color: #4d4d4d;
	font-size: 12px;
	text-align: center;
	text-shadow: 0 1px 1px rgba(255, 255, 255, 0.75);
	text-decoration: none;
	vertical-align: middle;
	cursor: pointer;
	background-color: #f5f5f5;
	background-image: -moz-linear-gradient(top, #ffffff, #e6e6e6);
	background-image: -ms-linear-gradient(top, #ffffff, #e6e6e6);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#e6e6e6));
	background-image: -webkit-linear-gradient(top, #ffffff, #e6e6e6);
	background-image: -o-linear-gradient(top, #ffffff, #e6e6e6);
	background-image: linear-gradient(top, #ffffff, #e6e6e6);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
	border: 1px solid #cccccc;
	border-bottom-color: #b3b3b3;
	border-radius: 3px;
	box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.2), 0 1px 2px rgba(0, 0, 0, 0.05);
	*display: inline;
	/* IE7 inline-block hack */

	*zoom: 1;
}
.btn:hover,
.btn:visited:hover {
 	background-color: #e6e6e6;
	background-position: 0 -15px;
}



/* general styles for hyperlink */
fieldset
{
	/*padding:15px;
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	border-radius:5px;*/
	/*background-color:#f9f9f9;*/


	padding:0px;
	border:none;


	/*white-space:nowrap;
	overflow:hidden;
	text-overflow: ellipsis;*/
	width:100%;

}
fieldset span,fieldset a{
	overflow:hidden;
	text-overflow: ellipsis;

}
/* outer div that holds everything */
#container
{
	padding:10px;
}
/* div of left box with log, list of databases, etc. */
#leftNav
{
	float:left;
	width:180px;
	padding:0px;
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	background-color:#FFF;
	padding-bottom:15px;
	border-radius:3px;
	font-size: 13px;

}
/* div holding the content to the right of the leftNav */
#content
{
	overflow:hidden;
	padding-left:10px;
}
/* div holding the login fields */
#loginBox
{
	width:500px;
	margin-left:auto;
	margin-right:auto;
	margin-top:50px;
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	background-color:#FFF;
	border-radius:3px;
}
/* div under tabs with tab-specific content */
#main
{
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	padding:15px;
	overflow:auto;
	background-color:#FFF;
	border-bottom-left-radius:3px;
	border-bottom-right-radius:3px;
	border-top-right-radius:3px;
}
#headerlinks{
	margin:0 10px;
}
.viewTable{
	width:100%;
	line-height: 1;
}
form[name="checkForm"] .viewTable td{
	height:1em;
	max-width:200px;
	overflow:hidden;
	white-space:nowrap;
	overflow:hidden;
	text-overflow: ellipsis;
}
/* odd-numbered table rows */
.td1
{
	background-color:#eaeaea;
	text-align:right;
	padding-left:10px;
	padding-right:10px;
}
/* even-numbered table rows */
.td2
{
	background-color:#f5f5f5;
	text-align:right;
	padding-left:10px;
	padding-right:10px;
}
/* table column headers */
.tdheader
{
	font-weight:bold;
	padding-left:10px;
	padding-right:10px;
	white-space:nowrap;

}
/* div holding the confirmation text of certain actions */
.confirm
{
	border-color:#ccc;
	border-width:1px;
	border-style:dashed;
	padding:15px;
	background-color:#fff;
}
/* tab navigation for each table */
.tab
{
	display:block;
	padding:5px;
	padding-right:8px;
	padding-left:8px;
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	margin-right:5px;
	float:left;
	border-bottom-style:none;
	position:relative;
	top:1px;
	padding-bottom:4px;
	background-color:#eaeaea;
	border-top-left-radius:3px;
	border-top-right-radius:3px;
}
/* pressed state of tab */
.tab_pressed
{
	display:block;
	padding:5px;
	padding-right:8px;
	padding-left:8px;
	border-color:#ccc;
	border-width:1px;
	border-style:solid;
	margin-right:5px;
	float:left;
	border-bottom-style:none;
	position:relative;
	top:1px;
	background-color:#FFF;
	cursor:default;
	border-top-left-radius:3px;
	border-top-right-radius:3px;
}
/* tooltip styles */
#tt
{
	position:absolute;
	display:block;
}
#tttop
{
	display:block;
	height:5px;
	margin-left:5px;
	overflow:hidden
}
#ttcont
{
	display:block;
	padding:2px 12px 3px 7px;
	margin-left:5px;
	background:#f3cece;
	color:#333
}
#ttbot
{
	display:block;
	height:5px;
	margin-left:5px;
	overflow:hidden
}
